@@ -4,12 +4,12 @@
 import inspect
 import traceback
 from loguru import logger
+from palp import settings
 from threading import Thread
-from urllib.parse import urlparse
-from palp import settings, Response
 from palp.network.request import Request
 from palp.item.item_base import BaseItem
 from palp.exception import exception_drop
+from palp.network.response import Response
 from palp.tool.short_module import import_module
 from palp.sequence.sequence_base import BaseSequence
 
@@ -103,7 +103,13 @@ class Parser(Thread):
         if not new_request.url.startswith('http') and response:
             new_request.url = response.urljoin(new_request.url)
 
-        new_request.callback = new_request.callback.__name__  # 转成字符串，不然无法序列化
+        # 添加 callback
+        if new_request.callback:
+            new_request.callback = new_request.callback.__name__  # 转成字符串，不然无法序列化
+        else:
+            new_request.callback = 'parse'
+
+        # 添加请求必须参数
         new_request.session = old_request.session  # 续上上一个的 session
         new_request.cookie_jar = old_request.cookie_jar  # 续上上一个的 cookie_jar
         self.queue.put(new_request)
